@@ -1,10 +1,8 @@
 from abc import ABC
 
-from PyGine import PyGinegame as Game
+from PyGine import PyGinegame as Game, Component
 from PyGine.Camera import Camera
 from PyGine.Transform import Transform
-
-
 class GameObject(ABC) :
     def __init__(self,name="",tags=["gameObjects"]):
         self.tags = tags
@@ -16,6 +14,7 @@ class GameObject(ABC) :
         self.Used = False
         self.started = False
 
+
     def start(self):
         """
         The start methode is called after the start of component
@@ -47,19 +46,18 @@ class GameObject(ABC) :
 
     def Mupdate(self,dt):
 
-
-        if(not self.destroy) :
-            for composant in self.Components:
-                composant.update(dt)
-                if(self.destroy) :
-                    break
-        else :
+        if(self.destroy) :
             Game.get().CurrentScene.removeGameObject(self)
+        else :
+            for composant in self.Components:
+                composant.Mupdate(dt)
+                if(self.destroy) :
+                    return
+
 
         if self.tracked :
-            Camera.DX = self.transform.position.x - Game.get().width/2
-            Camera.DY = self.transform.position.y - Game.get().height/2
-
+            Camera.PX = Camera.DX+self.transform.position.x - Game.get().width/2
+            Camera.PY = Camera.DY+self.transform.position.y - Game.get().height/2
         self.update(dt)
 
     def addComponent(self, composant):
@@ -67,12 +65,9 @@ class GameObject(ABC) :
             composant.Mstart()
         self.Components.append(composant)
 
-
-
     def AttachCamera(self,state):
         self.tracked = state
 
-
     def getComponent(self,class_) :
         for el in self.Components :
             if el.__class__ == class_ :
@@ -83,4 +78,5 @@ class GameObject(ABC) :
         self.end()
 
     def end(self):
-        pass
\ No newline at end of file
+        pass
+
